view src/pango-1-fixes.patch @ 2639:6e851800cb27

package pango: split DllMain patch and make it callable This allows users of this library to explicitly call the DllMain to run the necessary initialization.
author Matthias Gehre <M.Gehre@gmx.de>
date Tue, 19 Jun 2012 12:06:07 +0200
parents 059460e131a5
children c9c16664efca
line wrap: on
line source

From 971738e2fc2bc3faae52952dd08ee08b34ff4b86 Mon Sep 17 00:00:00 2001
From: Matthias Gehre <M.Gehre@gmx.de>
Date: Mon, 9 Jul 2012 13:13:49 +0200
Subject: [PATCH 1/4] Rename DllMain to pango_DllMain

---
 pango/pango-utils.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

-- 
1.7.9.5


From 779c533bf4354cbc747d82532f4798e6ef006d1b Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Wed, 29 Sep 2010 00:50:08 +0200
Subject: [PATCH 2/4] add missing lib to pango.pc for static linking

---
 pango.pc.in |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/pango.pc.in b/pango.pc.in
index 17a8b7a..16c5981 100644
--- a/pango.pc.in
+++ b/pango.pc.in
@@ -10,5 +10,5 @@ Description: Internationalized text handling
 Version: @VERSION@
 Requires: glib-2.0 gobject-2.0
 Requires.private: gmodule-no-export-2.0
-Libs: -L${libdir} -lpango-@PANGO_API_VERSION@ @PKGCONFIG_MATH_LIBS@
+Libs: -L${libdir} -lpango-@PANGO_API_VERSION@ @PKGCONFIG_MATH_LIBS@ -lusp10
 Cflags: -I${includedir}/pango-1.0
-- 
1.7.9.5


From 4340125c6b7f26106f7f021ec4c9612f7384e6c1 Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Fri, 15 Jun 2012 16:21:40 +0200
Subject: [PATCH 3/4] do not force shared for win32

---
 configure.in        |   14 --------------
 modules/Makefile.am |   17 +----------------
 2 files changed, 1 insertion(+), 30 deletions(-)

diff --git a/configure.in b/configure.in
index 8362280..6a000cc 100644
--- a/configure.in
+++ b/configure.in
@@ -147,20 +147,6 @@ CXXFLAGS="$CXXFLAGS -fno-rtti -fno-exceptions"
 # Win32 stuff
 #
 
-AC_LIBTOOL_WIN32_DLL
-AM_DISABLE_STATIC
-
-if test "$pango_os_win32" = "yes"; then
-  if test x$enable_static = xyes -o x$enable_static = x; then
-    AC_MSG_WARN([Disabling static library build, must build as DLL on Windows.])
-    enable_static=no
-  fi
-  if test x$enable_shared = xno; then
-    AC_MSG_WARN([Enabling shared library build, must build as DLL on Windows.])
-  fi
-  enable_shared=yes
-fi
-
 AM_PROG_LIBTOOL
 dnl when using libtool 2.x create libtool early, because it's used in configure
 m4_ifdef([LT_OUTPUT], [LT_OUTPUT])
diff --git a/modules/Makefile.am b/modules/Makefile.am
index dc8a2c8..dc22e59 100644
--- a/modules/Makefile.am
+++ b/modules/Makefile.am
@@ -26,22 +26,7 @@ RUN_QUERY_MODULES_TEST=true
 all-local: pango.modules
 endif
 
-install-data-local: $(top_builddir)/pango/pango-querymodules$(EXEEXT)
-	@if $(RUN_QUERY_MODULES_TEST) && test -z "$(DESTDIR)" ; then 	\
-	  echo $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango \&\& 	\
-	  $(top_builddir)/pango/pango-querymodules$(EXEEXT) 		\
-		\> $(DESTDIR)$(sysconfdir)/pango/pango.modules ;	\
-	  $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/pango && 		\
-	  $(top_builddir)/pango/pango-querymodules$(EXEEXT) 		\
-		> $(DESTDIR)$(sysconfdir)/pango/pango.modules ;		\
-	else								\
-	  echo "***" ; 							\
-	  echo "*** Warning: $(sysconfdir)/pango/pango.modules" ; 	\
-	  echo "*** not created" ; 					\
-	  echo "*** Generate this file on the target system" ; 		\
-	  echo "*** using pango-querymodules" ; 			\
-	  echo "***" ; 							\
-	fi
+install-data-local:
 
 uninstall-local:
 	$(RM) $(DESTDIR)$(sysconfdir)/pango/pango.modules
-- 
1.7.9.5


From ff735b2f71b07e7216856a473ed283eb24dd012a Mon Sep 17 00:00:00 2001
From: Mark Brand <mabrand@mabrand.nl>
Date: Mon, 18 Jun 2012 21:36:53 +0200
Subject: [PATCH 4/4] kill gtk-doc (MXE specific)

---
 Makefile.am  |    2 +-
 autogen.sh   |    8 --------
 configure.in |    9 +--------
 3 files changed, 2 insertions(+), 17 deletions(-)

diff --git a/Makefile.am b/Makefile.am
index b0b56ec..663503c 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,6 +1,6 @@
 ## Process this file with automake to create Makefile.in.
 
-SUBDIRS= pango modules pango-view examples docs tools tests build
+SUBDIRS= pango modules pango-view examples tools tests build
 
 EXTRA_DIST = 			\
 	autogen.sh		\
diff --git a/autogen.sh b/autogen.sh
index bc7c59c..4e1918c 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -7,14 +7,6 @@ test -n "$srcdir" || srcdir=.
 olddir=`pwd`
 cd "$srcdir"
 
-GTKDOCIZE=`which gtkdocize`
-if test -z $GTKDOCIZE; then
-	echo "*** No GTK-Doc found, please install it ***"
-	exit 1
-else
-	gtkdocize || exit $?
-fi
-
 AUTORECONF=`which autoreconf`
 if test -z $AUTORECONF; then
 	echo "*** No autoreconf found, please install it ***"
diff --git a/configure.in b/configure.in
index 6a000cc..e7538f6 100644
--- a/configure.in
+++ b/configure.in
@@ -615,14 +615,7 @@ dnl **************************
 dnl *** Checks for gtk-doc ***
 dnl **************************
 
-if $have_cairo ; then : ; else
-   if  test x$enable_gtk_doc = xyes ; then
-      AC_MSG_WARN([Cairo not present, disabling doc building])      
-      enable_gtk_doc=no
-   fi
-fi
-
-GTK_DOC_CHECK([1.0])
+enable_gtk_doc=no
 
 AC_ARG_ENABLE(man,
               AC_HELP_STRING([--enable-man],
diff --git a/pango/pango-utils.c b/pango/pango-utils.c
index c68e2d4..47ca433 100644
--- a/pango/pango-utils.c
+++ b/pango/pango-utils.c
@@ -692,12 +692,12 @@ pango_config_key_get (const char *key)
 
 #ifdef G_OS_WIN32
 
 /* DllMain function needed to tuck away the DLL handle */
 
 static HMODULE pango_dll;
 
 BOOL WINAPI
-DllMain (HINSTANCE hinstDLL,
+pango_DllMain (HINSTANCE hinstDLL,
 	 DWORD     fdwReason,
 	 LPVOID    lpvReserved)
 {
@@ -692,12 +692,12 @@ pango_config_key_get (const char *key)
 #ifdef G_OS_WIN32
 
-/* DllMain function needed to tuck away the DLL handle */
+/* pango_DllMain function needed to tuck away the DLL handle */
 
 static HMODULE pango_dll;
-- 
1.7.9.5